set daemon <poll_interval>

set logfile <plesk_dir>/var/modules/watchdog/log/monit.log
set pidfile <monit_pidfile>
set statefile <plesk_dir>/var/modules/watchdog/run/monit.state

set httpd port <monit_tcp_port> and use address 127.0.0.1
	allow 127.0.0.1
	allow <monit_login>:<monit_password>

set collector http://127.0.0.1:<wdcollect_port>

# Plesk apache
check process plesk_apache
	with pidfile "/var/run/sw-cp-server.pid"
	start = "<plesk_apache_start>"
	stop = "<plesk_apache_stop>"
	if failed host localhost port 8443 type tcpssl protocol http with timeout <plesk_apache_connection_timeout> seconds then restart
	if <plesk_apache_timeout_restarts> restarts within <plesk_apache_timeout_cycles> cycles then timeout
	every <plesk_apache_cycles> cycles
	mode <plesk_apache_mode>

# Apache
check process apache
	with pidfile "/var/run/apache2.pid"
	start = "<apache_start>"
	stop = "<apache_stop>"
	if failed host <default_apache_ip> port 80 send "GET / HTTP/1.1\r\nHost: <default_apache_ip>\r\n\r\n" expect "HTTP/1\.[01x] [1-4][0-9]{2} .*\r\n" with timeout <apache_connection_timeout> seconds then restart
	if <apache_timeout_restarts> restarts within <apache_timeout_cycles> cycles then timeout
	every <apache_cycles> cycles
	mode <apache_mode>

# Courier-IMAP
check process courier_imap
	with pidfile "/var/run/imapd.pid"
	start = "<courier_imap_start>"
	stop = "<courier_imap_stop>"
	if failed port 143 protocol imap with timeout <courier_imap_connection_timeout> seconds then restart
	if failed port 993 type tcpssl protocol imap with timeout <courier_imap_connection_timeout> seconds then restart
	if failed port 110 protocol pop with timeout <courier_imap_connection_timeout> seconds then restart
	if failed port 995 type tcpssl protocol pop with timeout <courier_imap_connection_timeout> seconds then restart
	if <courier_imap_timeout_restarts> restarts within <courier_imap_timeout_cycles> cycles then timeout
	every <courier_imap_cycles> cycles
	mode <courier_imap_mode>

# Bind
check process bind
	with pidfile "/var/named/run-root/var/run/named/named.pid"
	start = "<bind_start>"
	stop = "<bind_stop>"
    if failed port 53 type tcp with timeout <bind_connection_timeout> seconds then restart
    if failed port 53 type udp with timeout <bind_connection_timeout> seconds then restart
	if <bind_timeout_restarts> restarts within <bind_timeout_cycles> cycles then timeout
	every <bind_cycles> cycles
	mode <bind_mode>

# Tomcat
check process tomcat with pidfile "/var/lib/tomcat5/temp/tomcat5.pid"
	start = "<tomcat_start>"
	stop = "<tomcat_stop>"
	if failed port 9080 with timeout <tomcat_connection_timeout> seconds then restart
	if <tomcat_timeout_restarts> restarts within <tomcat_timeout_cycles> cycles then timeout
	every <tomcat_cycles> cycles
	mode <tomcat_mode>

# ColdFusion
check host coldfusion with address 127.0.0.1
	start = "<coldfusion_start>"
	stop = "<coldfusion_stop>"
	if failed port 8500 protocol http with timeout <coldfusion_connection_timeout> seconds then restart
	if <coldfusion_timeout_restarts> restarts within <coldfusion_timeout_cycles> cycles then timeout
	every <coldfusion_cycles> cycles
	mode <coldfusion_mode>

# MySQL
check process mysql
	with pidfile "/var/run/mysqld/mysqld.pid"
	start = "<mysql_start>"
	stop = "<mysql_stop>"
	if failed unixsocket /var/run/mysqld/mysqld.sock with timeout <mysql_connection_timeout> seconds then restart
	if <mysql_timeout_restarts> restarts within <mysql_timeout_cycles> cycles then timeout
	every <mysql_cycles> cycles
	mode <mysql_mode>

# PostgreSQL
check process postgresql
	with pidfile "/var/lib/postgresql/7.4/main/postmaster.pid"
	start = "<postgresql_start>"
	stop = "<postgresql_stop>"
	if failed unixsocket /var/run/postgresql/.s.PGSQL.5432 with timeout <postgresql_connection_timeout> seconds then restart
	if <postgresql_timeout_restarts> restarts within <postgresql_timeout_cycles> cycles then timeout
	every <postgresql_cycles> cycles
	mode <postgresql_mode>

# SpamAssassin
check process psa_spamassassin
	with pidfile "/var/run/spamd/spamd_full.pid"
	start = "<psa_spamassassin_start>"
	stop = "<psa_spamassassin_stop>"
	if failed unixsocket /tmp/spamd_full.sock <spamassassin_protocol_check> with timeout <psa_spamassassin_connection_timeout> seconds then restart
	if <psa_spamassassin_timeout_restarts> restarts within <psa_spamassassin_timeout_cycles> cycles then timeout
	every <psa_spamassassin_cycles> cycles
	mode <psa_spamassassin_mode>
