CREATE TABLE module_watchdog_param (
	param				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL PRIMARY KEY
,	val					VARCHAR(255) CHARACTER SET binary
) TYPE=InnoDB;

CREATE TABLE module_watchdog_service (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	name				VARCHAR(63) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	label				VARCHAR(63) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,   sort_val			SMALLINT UNSIGNED NOT NULL DEFAULT 65535
,	mon_status			ENUM ('monitored', 'notmonitored') NOT NULL DEFAULT 'notmonitored'
,	save_stats			ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	timeout				ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	timeout_restart_num	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	timeout_cycles_num	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	connection_timeout	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	start_cmd			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	stop_cmd			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	start_time			SMALLINT UNSIGNED NOT NULL DEFAULT 60

,						UNIQUE (name)
,						UNIQUE (label)
,						INDEX (name)
,						INDEX (sort_val)
) TYPE=InnoDB;

CREATE TABLE module_watchdog_disk (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	device				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	space_rate			FLOAT UNSIGNED NOT NULL DEFAULT 80
,	space_rate_unit		ENUM('percent', 'gigabyte', 'megabyte', 'kilobyte') DEFAULT 'percent'
,	inods_rate			FLOAT UNSIGNED NOT NULL DEFAULT 80
,	inods_rate_unit		ENUM('percent', 'file') NOT NULL DEFAULT 'percent'
,	command				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin

,						UNIQUE (device)
) TYPE=InnoDB;

CREATE TABLE module_watchdog_service_event (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	time				TIMESTAMP NOT NULL
,	service_id			INT UNSIGNED NOT NULL
,	name				ENUM ('NONWORK', 'RECOVER_WORK', 'TIMEOUT') NOT NULL

,						INDEX (time)
,						INDEX (service_id)
) TYPE=InnoDB;

CREATE TABLE module_watchdog_disk_event (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	time				TIMESTAMP NOT NULL
,	device				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	name				ENUM ('RATE_EXCESS', 'BACK_TO_NORMAL', 'UNMOUNTED', 'MOUNTED')
,	mount_point			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
,	fs_size				INT UNSIGNED
,	used_size			INT UNSIGNED
,	inodes_num			INT UNSIGNED
,	used_inodes			INT UNSIGNED

,						INDEX (time)
,						INDEX (device)
) TYPE=InnoDB;

CREATE TABLE module_watchdog_report (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	time				TIMESTAMP NOT NULL
,	name				VARCHAR(63) CHARACTER SET ascii COLLATE ascii_general_ci
,	type				ENUM ('SECUR_CHECK', 'PERIOD') NOT NULL

,						UNIQUE (name)
,						INDEX (type)
,						INDEX (time)
) TYPE=InnoDB;

CREATE TABLE module_watchdog_sys_stat (
	time				TIMESTAMP NOT NULL
,	type				ENUM ('CPU_USAGE', 'MAINMEM_USAGE') NOT NULL
						-- CPU_USAGE - percent
						-- MAINMEM_USAGE - kilobytes
,	value				INT UNSIGNED NOT NULL
,	service_id			INT UNSIGNED

,						INDEX (time)
,						INDEX (type)
,						INDEX (service_id)
) TYPE=InnoDB;

-- Inserting services.

INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('plesk_apache', 'Plesk Web Server', 10, '/etc/init.d/sw-cp-server start', '/etc/init.d/sw-cp-server stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('apache', 'Web Server (Apache)', 20, '/opt/psa/admin/bin/websrvmng --start', '/opt/psa/admin/bin/websrvmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('qmail', 'SMTP Server(Qmail)', 30, 60, '/opt/psa/admin/bin/mailmng --start-qmail-send', '/opt/psa/admin/bin/mailmng --stop-qmail-send');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('postfix', 'SMTP Server(Postfix)', 30, 60, '/opt/psa/admin/bin/mailmng --start-service --mail-component=mta', '/opt/psa/admin/bin/mailmng --stop-service --mail-component=mta');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('courier_imap', 'IMAP/POP3 Server (Courier-IMAP)', 40, 60, '/opt/psa/admin/bin/mailmng --start-maild', '/opt/psa/admin/bin/mailmng --stop-maild');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('bind', 'DNS Server (BIND)', 50, '/opt/psa/admin/bin/dnsmng --start', '/opt/psa/admin/bin/dnsmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_time, start_cmd, stop_cmd) VALUES ('tomcat', 'Tomcat', 60, 300, '/opt/psa/admin/bin/tomcatmng --start', '/opt/psa/admin/bin/tomcatmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('coldfusion', 'ColdFusion', 70, '/opt/psa/admin/bin/cfmng --start', '/opt/psa/admin/bin/cfmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('postgresql', 'PostgreSQL', 90, '/opt/psa/admin/bin/pg_manage --start', '/opt/psa/admin/bin/pg_manage --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_time, connection_timeout, start_cmd, stop_cmd) VALUES ('psa_spamassassin', 'Plesk SpamAssassin', 100, 120, 180, '/opt/psa/admin/bin/spamd --start', '/opt/psa/admin/bin/spamd --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('drweb', 'Parallels Premium Antivirus', 110, '/opt/psa/admin/bin/drwebmng --start', '/opt/psa/admin/bin/drwebmng --stop');

-- Inserting initial values of parameters.

INSERT INTO module_watchdog_param VALUES ('locale', 'en-US');
INSERT INTO module_watchdog_param VALUES ('refresh_pages', 'on');
INSERT INTO module_watchdog_param VALUES ('automonit', 'on');
INSERT INTO module_watchdog_param VALUES ('poll_interval', 300);
INSERT INTO module_watchdog_param VALUES ('storage_sysstat', 'on');
INSERT INTO module_watchdog_param VALUES ('sysstat_storage_time', '365');
INSERT INTO module_watchdog_param VALUES ('secur_scan_rate', 'weekly'); -- none, daily, weekly, monthly
INSERT INTO module_watchdog_param VALUES ('report_rate', 'weekly'); -- none, daily, weekly, monthly
INSERT INTO module_watchdog_param SELECT 'email_to', val FROM misc WHERE param='admin_email' LIMIT 1;
INSERT INTO module_watchdog_param SELECT 'email_from', CONCAT('watchdog@', val) FROM misc WHERE param='FullHostName' LIMIT 1;
INSERT INTO module_watchdog_param VALUES ('mail_servers', 'localhost');

INSERT INTO module_watchdog_param VALUES ('configured', 'no');
INSERT INTO module_watchdog_param VALUES ('monitrc_tplfile', '/opt/psa/etc/modules/watchdog/monitrc.tpl');
INSERT INTO module_watchdog_param VALUES ('monitrc_chkfile', '/tmp/monitrc.chk');
INSERT INTO module_watchdog_param VALUES ('monitrc_file', '/opt/psa/etc/modules/watchdog/monitrc');
INSERT INTO module_watchdog_param VALUES ('monitrc_tplfile_include_dir', '/opt/psa/etc/modules/watchdog/service.tpl.d');
INSERT INTO module_watchdog_param VALUES ('monitrc_file_include_dir', '/opt/psa/etc/modules/watchdog/service.d');
INSERT INTO module_watchdog_param VALUES ('monit_pidfile', '/opt/psa/var/modules/watchdog/run/monit.pid');
INSERT INTO module_watchdog_param VALUES ('monit_tcp_port', 2911);
INSERT INTO module_watchdog_param VALUES ('monit_login', 'monit');
INSERT INTO module_watchdog_param VALUES ('monit_password', CONCAT(LEFT( MD5(RAND()), 14), 'a'));
INSERT INTO module_watchdog_param VALUES ('wdcollect_port', '2912');
INSERT INTO module_watchdog_param VALUES ('wdcollect_cfgfile', '/opt/psa/etc/modules/watchdog/wdcollect.inc.php');
INSERT INTO module_watchdog_param VALUES ('wdcollect_logfile', '/opt/psa/var/modules/watchdog/log/wdcollect.log');
INSERT INTO module_watchdog_param VALUES ('wdcollect_pidfile', '/opt/psa/var/modules/watchdog/run/wdcollect.pid');

-- Enable actions

INSERT IGNORE INTO actions(name, descr, enabled) VALUES ('service_stop', 'Stop Service', 'true');
INSERT IGNORE INTO actions(name, descr, enabled) VALUES ('service_start', 'Start Service', 'true');

-- Create event handlers

SELECT @start_action_id:=id FROM actions WHERE name='service_start' LIMIT 1;
SELECT @stop_action_id:=id FROM actions WHERE name='service_stop' LIMIT 1;

INSERT INTO event_handlers (action_id, user, command) VALUES (@stop_action_id, 'root', '/opt/psa/admin/bin/modules/watchdog/wd --unmonit-service=<new_service> --plesk-name');

